##  Getting Fact Sheet Information
You can search and query for fact sheets by clicking Search Fact Sheets. In the resulting card, you can search for the fact sheet by name and optionally select a fact sheet type. If you don't select a fact sheet type, the search result will include all fact sheet types which has been configured by the admin to be available in the Microsoft Teams app. For more, see [Configuring Microsoft Teams Integration](https://help.sap.com/docs/leanix/ea/sap-leanix-app-for-microsoft-teams?locale=en-US&state=PRODUCTION&version=CLOUD#loio275ac61e7a44101497408ea8ccf9534f__configuring_microsoft_teams_integration).
Click Search to view a list of relevant fact sheets organized by fact sheet type. You can then select a fact sheet to open it or click View for a quick overview. This overview includes information like lifecycle, description, tags, parent relations, and subscribers. You can directly interact with the subscribers of these fact sheets and start conversations.
